Extensions

Struct Extensions 

pub struct Extensions(/* private fields */);
Represents certificate extensions.

Use Validator::leaf_extensions to retrieve the Extensions object for the leaf certificate (last certificate added to the validator).

Examples

let mut validator = attestation_validator::Validator::default();

validator.add_from_pem(std::fs::File::open("hsm-attestation-pem")?)?;

let extensions = validator.leaf_extensions()?;

Implementations

Source

impl Extensions

pub fn into_inner(self) -> HashMap<String, Vec<u8>>

Returns inner object holding a map from stringified OIDs to their raw values.

Examples
let mut validator = attestation_validator::Validator::default();

validator.add_from_pem(std::fs::File::open("hsm-attestation-pem")?)?;

let map = validator.leaf_extensions()?.into_inner();

assert!(map.contains_key("1.3.6.1.4.1.41482.4.1"));
pub fn get<'a>(&'a self, oid: &'a str) -> Result<Extension<'a>>

Returns a value of the extension if it is present or an error otherwise.

Examples
let mut validator = attestation_validator::Validator::default();

validator.add_from_pem(std::fs::File::open("hsm-attestation-pem")?)?;

let extension = validator.leaf_extensions()?.get("1.3.6.1.4.1.41482.4.1")?;
Errors

If the value for given oid is missing this function returns Error::OidMissing.